<?php

/**
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @package clearFusionCMS\module\hipchat
 * @copyright Copyright (c) 2013 clearFusionCMS. All rights reserved.
 * @link http://clearfusioncms.com
 */

/**
 * hipchatInstall Class
 *
 * Class for managing the HipChat module installation.
 *
 * @package clearFusionCMS\module\hipchat
 */
class hipchatInstall implements cfInstallInterface {
	/**
	 * The last error message.
	 *
	 * @var string
	 */
	protected $lastError = '';

	/**
	 * Return the last error.
	 *
	 * @return string The last error string.
	 */
	function getLastError() {
		return $this->lastError;
	}

	/**
	 * Install the module.
	 *
	 * @param flDb $db The database object to use.
	 * @return bool true if installed; else false.
	 */
	function install($db) {

		// Create permissions
		$ac = new flAcMgr($db);
		$ac->createPermissionGroup('cfHipChat', __noop('Hipchat'), 'hipchatBackend'); // 5000
		$ac->createPermission('cfHipChat.settings', __noop('Can edit HipChat module settings.'), 5010, 'hipchatBackend');

		// Add to all sites
		$siteMgr = new cfSiteManager($db);
		$sites = $siteMgr->listSites();
		foreach($sites as $site => $n) {
			$this->createSite($db, $site);
		}

		// Add listeners
		$em = clearFusionCMS::getEventManager();
		$em->addListener('system.notify', 'hipchatEvents', 'onNotify');

		return true;
	}

	/**
	 * Uninstall the module.
	 *
	 * @param flDb The database object to use.
	 * @return bool true if uninstalled; else false.
	 */
	function uninstall($db) {
		// Remove listeners
		$em = clearFusionCMS::getEventManager();
		$em->removeListener('system.notify', 'hipchatEvents', 'onNotify');

		// Remove permissions
		$ac = new flAcMgr($db);
		$ac->deletePermissionGroup('cfHipChat');

		// Delete the tables
		$siteMgr = new cfSiteManager($db);
		$sites = $siteMgr->listSites();
		foreach($sites as $site => $n) {
			$this->deleteSite($db, $site);
		}

		// Tell everyone this module has been removed
		clearFusionCMS::getEventManager()->notify(new flEvent('system.moduleRemoved', array(
			'module' => 'hipchat'
		)));

		return true;
	}

	/**
	 * Upgrade the module.
	 *
	 * @param flDb The database object to use.
	 * @param string $installedVer The installed version.
	 * @return bool true if upgraded; else false.
	 */
	function upgrade($db, $installedVer) {
		return true;
	}

	/**
	 * Create a new site.
	 *
	 * @param flDb $db The database object.
	 * @param string $site The short name of the site.
	 * @return bool true if the site was created; else false.
	 */
	function createSite($db, $site) {
		$siteMgr = new cfSiteManager($db);
		$cfg = $siteMgr->getSiteCfg('cfHipChat', $site);
		$cfg->token = '';
		$cfg->room = '';
		$cfg->level = 1;
		$cfg->notify = 1;
		$cfg->incSite = 0;

		return true;
	}

	/**
	 * Delete a site.
	 *
	 * @param flDb $db The database object.
	 * @param string $site The name of the site to delete.
	 * @return bool true if the site was deleted; else false.
	 */
	function deleteSite($db, $site) {
		$siteMgr = new cfSiteManager($db);
		$cfg = $siteMgr->getSiteCfg('cfHipChat', $site);
		$cfg->deleteNamespace();

		return true;
	}
}
