<?php

/**
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @package clearFusionCMS\module\hipchat
 * @copyright Copyright (c) 2013 - 2015 clearFusionCMS. All rights reserved.
 * @link http://clearfusioncms.com
 */

/**
 * hipchatSettings Class
 *
 * Class to implement settings for the HipChat module.
 *
 * @package clearFusionCMS\module\hipchat
 */
class hipchatSettings implements cfModuleSettingsInterface {

	/**
	 * Get a list of settings groups.
	 *
	 * @return array Array of setting groups, name => func name
	 */
	function getSettingsGroups() {
		if(!clearFusionCMS::getUser()->hasPermission('cfHipChat.settings'))
			return array();

		return array(
			__('Settings', 'hipchatBackend') => 'general'
		);
	}

	/**
	 * Implement HipChat settings.
	 *
	 * @param flForm $form The form object to use.
	 * @param flDb $db The database object.
	 * @return bool true if the settings were updated, false if failed to update or null if no change.
	 */
	function generalSetting($form, $db) {
		if(!clearFusionCMS::getUser()->hasPermission('cfHipChat.settings'))
			return null;

		$cfg = clearFusionCMS::getSiteConfig('cfHipChat');

		$token = new flFormElementText($form, 'token', $cfg->token);
		$token->setLabel(__('API Token', 'hipchatBackend'))
			->setDescription(clearFusionCMS::getController()->alertMessage('Info', __('This is available from your HipChat account, the token should be Notification only.', 'hipchatBackend')))
			->setRequired()
			->addValidator(new flFormValidatorRequired());

		$room = new flFormElementText($form, 'room', $cfg->room);
		$room->setLabel(__('Room', 'hipchatBackend'))
			->setDescription(clearFusionCMS::getController()->alertMessage('Info', __('The room name or ID to send messages to, this can be found under rooms within your HipChat account.', 'hipchatBackend')))
			->setRequired()
			->addValidator(new flFormValidatorRequired());

		$level = new flFormElementSelect($form, 'level', $cfg->level, array(100 => __('Disabled', 'hipchatBackend'), 1 => '1', 2 => '2', 3 => '3', 4 => '4', 5 => '5'));
		$level->setLabel(__('Notification Level', 'hipchatBackend'))
			->setDescription(__('Notifications below the selected level will be ignored.', 'hipchatBackend'));

		$notify = new flFormElementSelect($form, 'notify', $cfg->notify, array(100 => __('Disabled', 'hipchatBackend'), 1 => '1', 2 => '2', 3 => '3', 4 => '4', 5 => '5'));
		$notify->setLabel(__('Notify Users at or Above', 'hipchatBackend'))
			->setDescription(__('Notifications at or above the selected level will cause HipChat to notify room participants.', 'hipchatBackend'));

		$from = new flFormElementText($form, 'from', $cfg->get('from', 'CMS'));
		$from->setLabel(__('From Name', 'hipchatBackend'))
			->setRequired()
			->addValidator(new flFormValidatorRequired());

		$incSite = new flFormElementCheckbox($form, 'incSite', $cfg->incSite);
		$incSite->setLabel(__('Include Site Name in Notifications', 'hipchatBackend'));

		$submit = new flFormElementSubmit($form, 'update');
		$submit->setCaption(__('Update Settings', 'hipchatBackend'));

		$form->focusElement($token);

		if($form->isSubmitted() && $form->isValid()) {
			$cfg->token = $token->getValue();
			$cfg->room = $room->getValue();
			$cfg->level = $level->getValue();
			$cfg->notify = $notify->getValue();
			$cfg->from = $from->getValue();
			$cfg->incSite = $incSite->getValue();

			// Send a test message
			if($level->getValue() < 100) {
				$em = clearFusionCMS::getEventManager();
				$em->notify(new flEvent('system.notify', array(
					'level' => $level->getValue(),
					'message' => sprintf(__('%s has configured the HipChat module', 'hipchatBackend'), clearFusionCMS::getUser()->getUsername())
				)));
			}

			return true;
		}

		return null;
	}
}
